==> gtkmathview_0.6.4.orig.tar.gz: gtkmathview-0.6.4/src/engine/boxml/BoxMLBinContainerElement.cc <==
// Copyright (C) 2000-2003, Luca Padovani <luca.padovani@cs.unibo.it>.
//
// This file is part of GtkMathView, a Gtk widget for MathML.
// 
// GtkMathView is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// GtkMathView is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with GtkMathView; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// 
// For details, see the GtkMathView World-Wide-Web page,
// http://helm.cs.unibo.it/mml-widget, or send a mail to
// <luca.padovani@cs.unibo.it>

#include <config.h>

#include "BoxMLBinContainerElement.hh"
#include "BoxFormattingContext.hh"
#include "BoxGraphicDevice.hh"

BoxMLBinContainerElement::BoxMLBinContainerElement(const SmartPtr<BoxMLNamespaceContext>& context)
  : BoxMLElement(context)
{ }

BoxMLBinContainerElement::~BoxMLBinContainerElement()
{ }

AreaRef
BoxMLBinContainerElement::format(BoxFormattingContext& ctxt)
{
  if (dirtyLayout())
    {
      ctxt.push(this);
      if (SmartPtr<BoxMLElement> child = getChild())
	setArea(ctxt.getDevice()->wrapper(ctxt, child->format(ctxt)));
      ctxt.pop();
      resetDirtyLayout();
    }

  return getArea();
}

scaled
BoxMLBinContainerElement::getStep() const
{
  if (SmartPtr<BoxMLElement> child = getChild())
    return child->getStep();
  else
    return scaled::zero();
}

==> gtkmathview_0.6.5.orig.tar.gz: gtkmathview-0.6.5/src/engine/boxml/BoxMLBinContainerElement.cc <==
// Copyright (C) 2000-2003, Luca Padovani <luca.padovani@cs.unibo.it>.
//
// This file is part of GtkMathView, a Gtk widget for MathML.
// 
// GtkMathView is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// GtkMathView is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with GtkMathView; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// 
// For details, see the GtkMathView World-Wide-Web page,
// http://helm.cs.unibo.it/mml-widget, or send a mail to
// <luca.padovani@cs.unibo.it>

#include <config.h>

#include "BoxMLBinContainerElement.hh"
#include "FormattingContext.hh"
#include "BoxGraphicDevice.hh"

BoxMLBinContainerElement::BoxMLBinContainerElement(const SmartPtr<BoxMLNamespaceContext>& context)
  : BoxMLElement(context)
{ }

BoxMLBinContainerElement::~BoxMLBinContainerElement()
{ }

AreaRef
BoxMLBinContainerElement::format(FormattingContext& ctxt)
{
  if (dirtyLayout())
    {
      ctxt.push(this);
      if (SmartPtr<BoxMLElement> child = getChild())
	setArea(ctxt.BGD()->wrapper(ctxt, child->format(ctxt)));
      ctxt.pop();
      resetDirtyLayout();
    }

  return getArea();
}

scaled
BoxMLBinContainerElement::getStep() const
{
  if (SmartPtr<BoxMLElement> child = getChild())
    return child->getStep();
  else
    return scaled::zero();
}
